#include "qmlutils.h"
#include <QDateTime>

QmlUtils::QmlUtils(QObject *parent) :
    QObject(parent)
{
}

QString QmlUtils::durationFromSecs(int secs) {
    return Utils::durationFromSecs(secs);
}

QString QmlUtils::durationFromMSecs(int msecs) {
    return Utils::durationFromMSecs(msecs);
}

QString QmlUtils::fileSizeFromPath(const QString &filePath) {
    return Utils::fileSizeFromPath(filePath);
}

QString QmlUtils::fileSizeFromBytes(double bytes) {
    return Utils::fileSizeFromBytes(bytes);
}

QString QmlUtils::dateFromSecs(qint64 secs, bool showTime) {
    return Utils::dateFromSecs(secs, showTime);
}

QString QmlUtils::dateFromMSecs(qint64 msecs, bool showTime) {
    return Utils::dateFromMSecs(msecs, showTime);
}

qint64 QmlUtils::currentDateTime() {
    return QDateTime::currentMSecsSinceEpoch();
}

QString QmlUtils::localDateTimeFromString(const QString &dateTimeString, Qt::DateFormat format) {
    return Utils::localDateTimeFromString(dateTimeString, format);
}
